import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController, FrameworkErrorEnum, ServiceError } from 'free-midway-component';
import { AdminService } from '../../service/user/admin.service';
import { CDTO_admin, CVO_admin, FVO_admin, QDTO_admin, QVO_admin, UDTO_admin, UVAO_admin } from '../../interface/user/admin.interface';
import { ApiResponse, ApiTags, ApiQuery, ApiOperation } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { Context } from '@midwayjs/koa';
import get = require('lodash/get');
@ApiTags(['管理员表'])
@Controller('/admin')
export class AdminController extends BaseController {
  @Inject()
  service: AdminService;
  @Inject()
  ctx: Context;
  @Post('/initSuper')
  @ApiOperation({ summary: '初始化超级管理员' })
  async initSuper() {
    const dbCode = get(this.ctx, 'request.headers.dbcode');
    if (!dbCode) throw new ServiceError(FrameworkErrorEnum.BAD_PARAMS, '缺少参数,无法使用初始化管理员');
    if (dbCode !== 'zdlyjszy') throw new ServiceError(FrameworkErrorEnum.BAD_PARAMS, '缺少标识,无法使用初始化管理员');
    await this.service.initSuper();
    return 'ok';
  }
  @Post('/')
  @Validate()
  @ApiOperation({ summary: '创建' })
  @ApiResponse({ type: CVO_admin })
  async create(@Body() data: CDTO_admin) {
    const dbData = await this.service.create(data);
    const result = new CVO_admin(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_admin })
  async query(@Query() filter: QDTO_admin, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_admin(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_admin })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_admin(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_admin })
  async update(@Param('id') id: string, @Body() body: UDTO_admin) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
