import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ExamineeService } from '../../service/user/examinee.service';
import { CDTO_examinee, CVO_examinee, FVO_examinee, QDTO_examinee, QVO_examinee, UDTO_examinee, UVAO_examinee } from '../../interface/user/examinee.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['用户表'])
@Controller('/examinee')
export class ExamineeController extends BaseController {
  @Inject()
  service: ExamineeService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_examinee })
  async create(@Body() data: CDTO_examinee) {
    const dbData = await this.service.create(data);
    const result = new CVO_examinee(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_examinee })
  async query(@Query() filter: QDTO_examinee, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_examinee(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_examinee })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_examinee(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_examinee })
  async update(@Param('id') id: string, @Body() body: UDTO_examinee) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
